@@ -89,7 +89,7 @@ def set_cross_references(client: weaviate.client, model: dict, datapoints: list,
 
     # initialize the batch variables
     pointcount = batchcount = 0
-    batch = weaviate.ReferenceBatchRequest()
+    client.batch.shape
 
     if len(datapoints) > 0:
         for point in datapoints:
@@ -103,20 +103,19 @@ def set_cross_references(client: weaviate.client, model: dict, datapoints: list,
                     if entity in entities:
 
                         entuuid = generate_uuid_for_entity(entity, point[key])
-                        batch.add(produuid, point['classname'], "of" + entity, entuuid)
+                        client.batch.add_reference(produuid, point['classname'], "of" + entity, entuuid)
 
                         batchcount += 1
                         if batchcount >= maxbatch:
-                            result = client.batch.create_references(batch)
+                            result = client.batch.create_references()
                             check_batch_result(result)
-
-                            batch = weaviate.ReferenceBatchRequest()
+                            client.batch.shape
                             batchcount = 0
                             if verbose:
                                 print("Cross reference data points -----------:", pointcount, end="\r")
 
         if batchcount > 0:
-            result = client.batch.create_references(batch)
+            result = client.batch.create_references()
             check_batch_result(result)
             if verbose:
                 print("Cross reference data points -----------:", pointcount)
@@ -139,27 +138,28 @@ def import_entities(client: weaviate.client, entities: list, maxbatch: int, verb
     """
 
     totalcount = batchcount = 0
-    batch = weaviate.ObjectsBatchRequest()
+    #batch = weaviate.ObjectsBatchRequest()
+    client.batch.shape
 
     for entity in entities:
         for name in entities[entity]:
             thing = {}
             thing['name'] = name
             newuuid = generate_uuid_for_entity(entity, name)
-            batch.add(thing, entity, newuuid)
+            client.batch.add_data_object(thing, entity, newuuid)
 
             batchcount += 1
             totalcount += 1
             if batchcount >= maxbatch:
                 if verbose:
                     print("Entities imported into Weaviate -------:", totalcount, end="\r")
-                result = client.batch.create_objects(batch)
+                result = client.batch.create_objects()
                 check_batch_result(result)
-                batch = weaviate.ObjectsBatchRequest()
+                client.batch.shape
                 batchcount = 0
 
     if batchcount > 0:
-        result = client.batch.create_objects(batch)
+        result = client.batch.create_objects()
         check_batch_result(result)
         if verbose:
             print("Entities imported into Weaviate -------:", totalcount)
@@ -194,7 +194,7 @@ def import_datapoints(client: weaviate.client, model: dict, datapoints: list, ma
     """
 
     totalcount = batchcount = 0
-    batch = weaviate.ObjectsBatchRequest()
+    client.batch.shape
 
     if len(datapoints) > 0:
         classname = datapoints[0]['classname']
@@ -211,14 +211,14 @@ def import_datapoints(client: weaviate.client, model: dict, datapoints: list, ma
 
             newuuid = generate_uuid_for_datapoint(model, point)
 
-            batch.add(thing, point['classname'], newuuid)
+            client.batch.add_data_object(thing, point['classname'], newuuid)
             batchcount += 1
             totalcount += 1
 
             if batchcount >= maxbatch:
-                result = client.batch.create_objects(batch)
+                result = client.batch.create_objects()
                 check_batch_result(result)
-                batch = weaviate.ObjectsBatchRequest()
+                client.batch.shape
                 batchcount = 0
                 batchNumber += 1
                 if verbose:
@@ -226,7 +226,7 @@ def import_datapoints(client: weaviate.client, model: dict, datapoints: list, ma
 
         # if there are left over points in the last batch, import these last data points
         if batchcount > 0:
-            result = client.batch.create_objects(batch)
+            result = client.batch.create_objects()
             check_batch_result(result)
             if verbose:
                 print("Data points imported into Weaviate ----:", totalcount)
