@@ -25,7 +25,7 @@ def get_max_batch_number(client, classname: str) -> int:
     if classname is not None:
         query = template % (classname)
         result = client.query.raw(query)
-        if result is not None and result['errors'] is None and len(result['data']['Aggregate'][classname]) > 0:
+        if result is not None and 'errors' not in result and len(result['data']['Aggregate'][classname]) > 0:
             maxnumber = int(result['data']['Aggregate'][classname][0]['batchNumber']['maximum'])
     return maxnumber
 
@@ -39,7 +39,7 @@ def get_classification_configuration(client):
     if client is not None:
         result = client.query.raw(query)
 
-        if result is not None and result['errors'] is None:
+        if result is not None and 'errors' not in result:
             if len(result['data']['Get']["ClassificationConfiguration"]) > 0:
                 ccuuid = result['data']['Get']["ClassificationConfiguration"][0]["_additional"]["id"]
 
@@ -55,7 +55,7 @@ def count_number_of_datapoints(client, classname):
     result = client.query.raw(query)
 
     if result is not None:
-        if result['errors'] is None:
+        if errors not in result:
             count = result['data']['Aggregate'][classname][0]["meta"]["count"]
         else:
             print(result['errors'])
@@ -71,7 +71,7 @@ def count_number_of_unvalidated_datapoints(client, classname):
     result = client.query.raw(query)
 
     if result is not None:
-        if result['errors'] is None:
+        if 'errors' not in result:
             count = result['data']['Aggregate'][classname][0]["meta"]["count"]
         else:
             print(result['errors'])
@@ -87,7 +87,7 @@ def count_number_of_datapoints(client, classname):
     result = client.query.raw(query)
 
     if result is not None:
-        if result['errors'] is None:
+        if 'errors' not in result:
             count = result['data']['Aggregate'][classname][0]["meta"]["count"]
         else:
             print(result['errors'])
@@ -218,11 +218,8 @@ def get_classified_datapoints(client, classification, maxbatch, fields=None):
     if client is not None:
 
         classname = classification['classify_class']
-        count = count_number_of_unvalidated_datapoints(client, classname)
-
-        # if count > maxbatch, we need to pull the result out in batches.
-        batchcount = math.ceil(count / maxbatch)
-        for batch in range(1, batchcount + 1):
+        number = get_max_batch_number(client, classname)
+        for batch in range(1, number + 1):
 
             query = create_get_query_batch_number(client, classification, batch, fields)
             result = client.query.raw(query)
