@@ -467,6 +467,10 @@ def _create_classification_config_class(modulename: str) -> dict:
     prop = _create_prop('confidenceBuckets', 'int', "Number of conf. buckets in a classification", modulename)
     newclass['properties'].append(prop)
 
+    # Add a property that holds the maximum batch size
+    prop = _create_prop('maxBatchSize', 'int', "Maximum batch size", modulename)
+    newclass['properties'].append(prop)
+
     return newclass
 
 
